@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
-from django.conf.urls import patterns, include, url
+from django.conf.urls import include, patterns, url
+
 from .views import SmartProxyView
 
 urlpatterns = patterns('',
